#include "record.ih"

Record::~Record()
{
    --s_count;
}
